@@ -1,16 +1,11 @@
 import os
 import json
 import platform
-import pathlib
+import tempfile
 
 import requests
 
-if platform.system() == 'Windows':
-    CACHE_PATH = pathlib.WindowsPath(os.getenv('TEMP', '~') + '/former-spec.cached.json').expanduser()
-else:
-    CACHE_PATH = pathlib.Path('/tmp/former-spec.cached.json')
-CACHE_PATH = str(CACHE_PATH)
-
+CACHE_PATH = tempfile.gettempdir() + '/former-spec.cached.json'
 
 def specification():
     if os.path.exists(CACHE_PATH):
